@@ -31,9 +31,7 @@ def isserviceenabled(SERVICENAME):
     output = subprocess.check_output("systemctl status %s" % SERVICENAME, shell=True)
     output = output.decode()
     if "enabled; vendor preset" in output and os.path.isfile("/usr/lib/systemd/system/%s.service" % SERVICENAME):
-        print(bcolors.OKGREEN + SERVICENAME + " Service is enabled"  + bcolors.ENDC)
+        print(bcolors.OKGREEN + SERVICENAME + " service is enabled"  + bcolors.ENDC)
     else: 
-        print(bcolors.FAIL + SERVICENAME + " Service is not enabled"  + bcolors.ENDC)
+        print(bcolors.FAIL + SERVICENAME + " service is not enabled"  + bcolors.ENDC)
         sys.exit(1)
-
-
